changeset 20048:5324d8b2322b

(read_list): Don't recognize Vload_file_name specially if it is nil.
author Karl Heuer <kwzh@gnu.org>
date Wed, 15 Oct 1997 22:45:35 +0000
parents 735f0cdfc5b9
children 69e6aa6e413e
files src/lread.c
diffstat 1 files changed, 5 insertions(+), 1 deletions(-) [+]
line wrap: on
line diff
--- a/src/lread.c	Wed Oct 15 22:41:09 1997 +0000
+++ b/src/lread.c	Wed Oct 15 22:45:35 1997 +0000
@@ -130,7 +130,8 @@
 static int read_from_string_index;
 static int read_from_string_limit;
 
-/* This contains the last string skipped with #@.  */
+/* This contains the last string skipped with #@, but only on some systems.
+     On other systems we can't put the string here.  */
 static char *saved_doc_string;
 /* Length of buffer allocated in saved_doc_string.  */
 static int saved_doc_string_size;
@@ -1517,6 +1518,7 @@
 	      for (i = 0; i < nskip && c >= 0; i++)
 		c = READCHAR;
 	    }
+
 	  goto retry;
 	}
       if (c == '$')
@@ -1942,6 +1944,7 @@
 
       /* While building, if the list starts with #$, treat it specially.  */
       if (EQ (elt, Vload_file_name)
+	  && ! NILP (elt)
 	  && !NILP (Vpurify_flag))
 	{
 	  if (NILP (Vdoc_file_name))
@@ -1960,6 +1963,7 @@
 			   Ffile_name_nondirectory (elt));
 	}
       else if (EQ (elt, Vload_file_name)
+	       && ! NILP (elt)
 	       && load_force_doc_strings)
 	doc_reference = 2;